class ResponseTypes:
    RENDERABLE = "1"
    STATIC_FILE = "2"
    PROXY = "3"
    STATIC_FILE_WITH_PROCESS = "4"
    RENDERED = "5"
